@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include "driveservice.h"
@@ -34,6 +34,7 @@ namespace Private
     static const QString AppsBasePath(QStringLiteral("/drive/v2/about"));
     static const QString FilesBasePath(QStringLiteral("/drive/v2/files"));
     static const QString ChangeBasePath(QStringLiteral("/drive/v2/changes"));
+    static const QString TeamdriveBasePath(QStringLiteral("/drive/v2/teamdrives"));
 }
 
 namespace DriveService
@@ -286,6 +287,20 @@ QUrl modifyRevisionUrl(const QString &fileId, const QString &revisionId)
     return url;
 }
 
+QUrl fetchTeamdriveUrl(const QString &teamdriveId)
+{
+    QUrl url(Private::GoogleApisUrl);
+    url.setPath(Private::TeamdriveBasePath % QLatin1Char('/') % teamdriveId);
+    return url;
+}
+
+QUrl fetchTeamdrivesUrl()
+{
+    QUrl url(Private::GoogleApisUrl);
+    url.setPath(Private::TeamdriveBasePath);
+    return url;
+}
+
 } // namespace DriveService
 
 } // namespace KGAPI2
