@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KGAPI2_DRIVEFILEABSTRACTMODIFYJOB_H
@@ -26,7 +26,7 @@
 #include "modifyjob.h"
 #include "kgapidrive_export.h"
 
-#include <QtCore/QStringList>
+#include <QStringList>
 
 namespace KGAPI2
 {
@@ -40,19 +40,19 @@ class KGAPIDRIVE_EXPORT FileAbstractModifyJob : public KGAPI2::ModifyJob
 
   public:
     explicit FileAbstractModifyJob(const QString &fileId,
-                                   const AccountPtr &account, QObject *parent = 0);
+                                   const AccountPtr &account, QObject *parent = nullptr);
     explicit FileAbstractModifyJob(const QStringList &filesIds,
-                                   const AccountPtr &account, QObject *parent = 0);
+                                   const AccountPtr &account, QObject *parent = nullptr);
     explicit FileAbstractModifyJob(const FilePtr &file,
-                                   const AccountPtr &account, QObject *parent = 0);
+                                   const AccountPtr &account, QObject *parent = nullptr);
     explicit FileAbstractModifyJob(const FilesList &files,
-                                   const AccountPtr &account, QObject *parent = 0);
-    virtual ~FileAbstractModifyJob();
+                                   const AccountPtr &account, QObject *parent = nullptr);
+    ~FileAbstractModifyJob() override;
 
   protected:
-    void start() Q_DECL_OVERRIDE;
+    void start() override;
     KGAPI2::ObjectsList handleReplyWithItems(const QNetworkReply *reply,
-                                                     const QByteArray &rawData) Q_DECL_OVERRIDE;
+                                                     const QByteArray &rawData) override;
 
     virtual QUrl url(const QString &fileId) = 0;
 
